@@ -188,7 +188,8 @@ class Definition:
 		validator = Schemas.ModelValidator(
 				name=display_name,
 				allow_unknown_fields=self.data_format.allow_unknown_fields,
-				case_sensitive=self.data_format.case_sensitive
+				case_sensitive=self.data_format.case_sensitive,
+				load_defaults=self.data_format.load_defaults
 			)
 		required = set()
 		optional = set()
@@ -201,30 +202,33 @@ class Definition:
 		default_values = {}
 		fields = self.list_fields()
 		for name in fields:
-			field_definition = fields[name]
-			if field_definition is None:
-				field_definition = Schemas.Field()
-			if field_definition.required:
+			field = fields[name]
+			field_definition_name = name
+			if field.definition_name is not None:
+				field_definition_name = field.definition_name
+			field_definition = Index.get(field_definition_name)
+			if field.unvalidated is not True:
+				dependencies[name] = field_definition.dependencies
+			if field is None:
+				field = Schemas.Field()
+			if field.required:
 				required.add(name)
 			else:
 				optional.add(name)
-			if field_definition.ignored:
+			if field.ignored:
 				ignored.add(name)
-			if field_definition.unvalidated:
+			if field.unvalidated:
 				unvalidated.add(name)
-			if field_definition.definition_name:
-				definition_names[name] = field_definition.definition_name
-			if field_definition.output_name:
-				output_names[name] = field_definition.output_name
-			if field_definition.input_name:
-				input_names[name] = field_definition.input_name
-			if not Utils.Empty.isempty(field_definition.default_value):
+			if field.definition_name:
+				definition_names[name] = field.definition_name
+			if field.output_name:
+				output_names[name] = field.output_name
+			if field.input_name:
+				input_names[name] = field.input_name
+			if not Utils.Empty.isempty(field.default_value):
+				default_values[name] = field.default_value
+			else:
 				default_values[name] = field_definition.default_value
-			definition_name = name
-			if field_definition.definition_name is not None:
-				definition_name = field_definition.definition_name
-			if field_definition.unvalidated is not True:
-				dependencies[name] = Index.get(definition_name).dependencies
 		validator.add_spec(
 				required=required,
 				optional=optional,
@@ -421,6 +425,10 @@ class Definition:
 				if name.startswith('_'):
 					continue
 				fields[name] = getattr(model, name)
+				if fields[name] is None:
+					fields[name] = Schemas.Field(definition_name=Index.get(name))
+				elif fields[name].definition_name is None:
+					fields[name].definition_name = name
 		for k in fields:
 			f = fields[k]
 			if f.input_name is None:
