@@ -10,6 +10,7 @@ class Schema:
 	allow_unknown_fields = False
 	display_name = None
 	case_sensitive = True
+	load_defaults = False
 
 	def __init__(
 				self,
@@ -17,7 +18,8 @@ class Schema:
 				model_name=Utils.Empty,
 				allow_unknown_fields=Utils.Empty,
 				display_name=Utils.Empty,
-				case_sensitive=Utils.Empty
+				case_sensitive=Utils.Empty,
+				load_defaults=Utils.Empty
 			):
 		def _set_member(name, value):
 			if Utils.Empty.isempty(value):
@@ -32,6 +34,10 @@ class Schema:
 		_set_member('allow_unknown_fields', allow_unknown_fields)
 		_set_member('display_name', display_name)
 		_set_member('case_sensitive', case_sensitive)
+		_set_member('load_defaults', load_defaults)
+		if self.model_name is None:
+			self.model_name = model.__class__.__name__
+
 
 	def to_json_dict(self):
 		def _is_default(name, value):
@@ -204,10 +210,11 @@ class Validator:
 
 
 class ModelValidator:
-	def __init__(self, name, allow_unknown_fields, case_sensitive):
+	def __init__(self, name, allow_unknown_fields, case_sensitive, load_defaults):
 		self.name = name
 		self.allow_unknown_fields = allow_unknown_fields
 		self.case_sensitive = case_sensitive
+		self.load_defaults = load_defaults
 		self.required = set()
 		self.optional = set()
 		self.ignored = set()
@@ -278,8 +285,6 @@ class ModelValidator:
 				return source[value_name]
 		elif hasattr(source, value_name):
 			return getattr(source, value_name)
-		#if field_name in self.default_values:
-		#	return self.default_values[field_name]
 		raise Config.exception_factory.create_input_error(fqn, 'Missing required value.')
 
 	def _get_output_value(self, value_name, source):
@@ -326,6 +331,9 @@ class ModelValidator:
 		self._update_dependency_order()
 		# Build kw
 		##########
+		if self.load_defaults is True:
+			for field_name in self.optional:
+				kw[field_name] = self.default_values[field_name]
 		for field_name in field_names:
 			if field_name in missing:
 				missing.remove(field_name)
